# Transition from Transformation Items/Project Fact Sheet to Initiative
### On this page
  * [Approach 1: Renaming the Label via Meta Model configuration](https://help.sap.com/docs/leanix/ea/transition-from-transformation-items-project-fact-sheet-to-initiative#approach-1:-renaming-the-label-via-meta-model-configuration)
  * [Approach 2: De-provision the category field and recreate it again](https://help.sap.com/docs/leanix/ea/transition-from-transformation-items-project-fact-sheet-to-initiative#approach-2:-de-provision-the-category-field-and-recreate-it-again)


SAP LeanIX has updated its Meta Model v3 and is rolling out the evolved Meta Model v4 to workspaces for new customers. Existing customers who are using the [Meta Model v3](https://help.sap.com/docs/leanix/ea/meta-model-v3?locale=en-US&state=PRODUCTION&version=CLOUD) are not obliged to migrate but can decide proactively to use the Meta Model v4. Many users are actively embracing [Meta Model](https://help.sap.com/docs/leanix/ea/meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of the SAP LeanIX meta model and its key concepts."), and you can find detailed guidance on this process [here](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to configure your workspace to align with the Meta Model v4.").
This documentation provides instructions to users of SAP LeanIX Architecture and Road Map Planning on moving from Transformation Items or Project Fact Sheet type to Initiative Fact Sheet. Whether you continue to use the Transformation Item Fact Sheet type after you migrated to the new BTM module (now known as SAP LeanIX Architecture and Road Map Planning) OR you switched to the Projects Fact Sheet type, in this documentation, you will find instructions on how to configure the Transformation Item/Project Fact Sheet type to the Initiative Fact Sheet.
Here are two different approaches based on your situation to achieve this.
